@@ -1,9 +1,9 @@
 package App::perlmv::scriptlet::remove_common_suffix;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-03'; # DATE
+our $DATE = '2020-08-04'; # DATE
 our $DIST = 'App-perlmv'; # DIST
-our $VERSION = '0.602'; # VERSION
+our $VERSION = '0.603'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ our $SCRIPTLET = {
 
 1;
 
-# ABSTRACT:
+# ABSTRACT: Remove suffix that are common to all args, while preserving extension, e.g. (1-radiolab.mp3, 2-radiolab.mp3) -> (1.mp3, 2.mp3)
 
 __END__
 
@@ -44,11 +44,11 @@ __END__
 
 =head1 NAME
 
-App::perlmv::scriptlet::remove_common_suffix
+App::perlmv::scriptlet::remove_common_suffix - Remove suffix that are common to all args, while preserving extension, e.g. (1-radiolab.mp3, 2-radiolab.mp3) -> (1.mp3, 2.mp3)
 
 =head1 VERSION
 
-This document describes version 0.602 of App::perlmv::scriptlet::remove_common_suffix (from Perl distribution App-perlmv), released on 2020-08-03.
+This document describes version 0.603 of App::perlmv::scriptlet::remove_common_suffix (from Perl distribution App-perlmv), released on 2020-08-04.
 
 =head1 HOMEPAGE
 
@@ -66,6 +66,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<perlmv> (from L<App::perlmv>)
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
